@@ -1,10 +1,8 @@
 # The COPYRIGHT file at the top level of this repository contains the full
 # copyright notices and license terms.
 from trytond.pool import Pool
-from . import batch
-from . import journal
-from . import move
-from . import party
+
+from . import batch, journal, move, party
 
 __all__ = ['register']
 
