@@ -4,16 +4,16 @@ import copy
 from decimal import Decimal
 from time import *
 
-from trytond.model import Workflow, ModelView, ModelSQL, fields
-from trytond.wizard import Wizard, StateView, StateAction, StateTransition, \
-    Button
-from trytond.pool import Pool
-from trytond.rpc import RPC
-from trytond.pyson import Get, Equal, Eval, Not, In, Bool, Or, And, If, \
-    PYSONEncoder
-from trytond.transaction import Transaction
 from trytond.exceptions import UserError
 from trytond.i18n import gettext
+from trytond.model import ModelSQL, ModelView, Workflow, fields
+from trytond.pool import Pool
+from trytond.pyson import (
+    And, Bool, Equal, Eval, Get, If, In, Not, Or, PYSONEncoder)
+from trytond.rpc import RPC
+from trytond.transaction import Transaction
+from trytond.wizard import (
+    Button, StateAction, StateTransition, StateView, Wizard)
 
 _STATES = {
     'readonly': Equal(Eval('state'), 'closed'),
